@@ -2,8 +2,8 @@
 /* vim:set et sts=4: */
 /* ibus - The Input Bus
  * Copyright (C) 2008-2013 Peng Huang <shawn.p.huang@gmail.com>
- * Copyright (C) 2015-2018 Takao Fujiwara <takao.fujiwara1@gmail.com>
- * Copyright (C) 2008-2018 Red Hat, Inc.
+ * Copyright (C) 2015-2019 Takao Fujiwara <takao.fujiwara1@gmail.com>
+ * Copyright (C) 2008-2019 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -73,7 +73,9 @@ struct _IBusIMContext {
     GCancellable    *cancellable;
     GQueue          *events_queue;
 
-    gboolean use_button_press_event;
+#if !GTK_CHECK_VERSION (3, 93, 0)
+    gboolean         use_button_press_event;
+#endif
 };
 
 struct _IBusIMContextClass {
@@ -137,12 +139,12 @@ static void     ibus_im_context_set_surrounding
 
 /* static methods*/
 static void     _ibus_context_update_preedit_text_cb
-                                           (IBusInputContext   *ibuscontext,
-                                            IBusText           *text,
-                                            gint                cursor_pos,
-                                            gboolean            visible,
-                                            guint               mode,
-                                            IBusIMContext      *ibusimcontext);
+                                            (IBusInputContext   *ibuscontext,
+                                             IBusText           *text,
+                                             gint                cursor_pos,
+                                             gboolean            visible,
+                                             guint               mode,
+                                             IBusIMContext      *ibusimcontext);
 static void     _create_input_context       (IBusIMContext      *context);
 static gboolean _set_cursor_location_internal
                                             (IBusIMContext      *context);
@@ -172,7 +174,6 @@ static void     _create_fake_input_context  (void);
 static gboolean _set_content_type           (IBusIMContext      *context);
 
 
-
 static GType                _ibus_type_im_context = 0;
 static GtkIMContextClass    *parent_class = NULL;
 
@@ -313,7 +314,6 @@ _process_key_event_done (GObject      *object,
 {
     IBusInputContext *context = (IBusInputContext *)object;
     GdkEventKey *event = (GdkEventKey *) user_data;
-
     GError *error = NULL;
     gboolean retval = ibus_input_context_process_key_event_async_finish (
             context,
@@ -362,12 +362,10 @@ _process_key_event (IBusInputContext *context,
         retval = TRUE;
     }
 
-    if (retval) {
+    if (retval)
         event->state |= IBUS_HANDLED_MASK;
-    }
-    else {
+    else
         event->state |= IBUS_IGNORED_MASK;
-    }
 
     return retval;
 }
@@ -1074,8 +1072,9 @@ ibus_im_context_reset (GtkIMContext *context)
         /* Commented out ibus_im_context_clear_preedit_text().
          * Hangul needs to receive the reset callback with button press
          * but other IMEs should avoid to receive the reset callback
-         * so the signal would need to be customized with GtkSetting.
-         * IBus uses button-press-event instead.
+         * by themselves.
+         * IBus uses button-press-event instead until GTK is fixed.
+         * https://gitlab.gnome.org/GNOME/gtk/issues/1534
          */
         ibus_input_context_reset (ibusimcontext->ibuscontext);
     }
@@ -1124,6 +1123,10 @@ ibus_im_context_get_preedit_string (GtkIMContext   *context,
 
 
 #if !GTK_CHECK_VERSION (3, 93, 0)
+/* Use the button-press-event signal until GtkIMContext always emits the reset
+ * signal.
+ * https://gitlab.gnome.org/GNOME/gtk/merge_requests/460
+ */
 static gboolean
 ibus_im_context_button_press_event_cb (GtkWidget      *widget,
                                        GdkEventButton *event,
@@ -1156,11 +1159,13 @@ _connect_button_press_event (IBusIMContext *ibusimcontext,
                     "button-press-event",
                     G_CALLBACK (ibus_im_context_button_press_event_cb),
                     ibusimcontext);
+            ibusimcontext->use_button_press_event = TRUE;
         } else {
             g_signal_handlers_disconnect_by_func (
                     widget,
                     G_CALLBACK (ibus_im_context_button_press_event_cb),
                     ibusimcontext);
+            ibusimcontext->use_button_press_event = FALSE;
         }
     }
 }
@@ -1187,7 +1192,7 @@ ibus_im_context_set_client_window (GtkIMContext *context, GdkWindow *client)
     if (client != NULL) {
         ibusimcontext->client_window = g_object_ref (client);
 #if !GTK_CHECK_VERSION (3, 93, 0)
-        if (ibusimcontext->use_button_press_event)
+        if (!ibusimcontext->use_button_press_event)
             _connect_button_press_event (ibusimcontext, TRUE);
 #endif
     }
@@ -1501,6 +1506,7 @@ _key_is_modifier (guint keyval)
         return FALSE;
     }
 }
+
 /* Copy from gdk */
 static GdkEventKey *
 _create_gdk_event (IBusIMContext *ibusimcontext,
@@ -1654,14 +1660,14 @@ _ibus_context_update_preedit_text_cb (IBusInputContext  *ibuscontext,
         ibusimcontext->preedit_attrs = NULL;
     }
 
+#if !GTK_CHECK_VERSION (3, 93, 0)
     if (!ibusimcontext->use_button_press_event &&
         mode == IBUS_ENGINE_PREEDIT_COMMIT) {
-#if !GTK_CHECK_VERSION (3, 93, 0)
-        if (ibusimcontext->client_window)
+        if (ibusimcontext->client_window) {
             _connect_button_press_event (ibusimcontext, TRUE);
-#endif
-        ibusimcontext->use_button_press_event = TRUE;
+        }
     }
+#endif
 
     str = text->text;
     ibusimcontext->preedit_string = g_strdup (str);
