@@ -127,12 +127,14 @@ parse_compose_value (IBusComposeData  *compose_data,
         compose_data->values[0] = g_ascii_strtoll(p, NULL, 8);
         compose_data->values[1] = 0;
     } else {
-        if (!(uchars = g_utf8_to_ucs4 (ustr, -1, NULL, NULL, &error)) ||
-            !uchars[0]) {
+        if (!(uchars = g_utf8_to_ucs4 (ustr, -1, NULL, NULL, &error))) {
             g_warning ("Invalid Unicode: %s: %s in %s:",
                        error->message, ustr, line);
             g_error_free (error);
             goto fail;
+        } else if (!uchars[0]) {
+            g_warning ("Invalid Unicode: \"\" in %s:", line);
+            goto fail;
         }
 
         for (up = uchars; *up; up++) {
@@ -148,7 +150,7 @@ parse_compose_value (IBusComposeData  *compose_data,
             } else {
                 compose_data->values = g_renew (gunichar,
                                                 compose_data->values,
-                                                n_uchars + 1);
+                                                n_uchars + 2);
             }
             compose_data->values[n_uchars++] = *up;
         }
@@ -1058,6 +1060,7 @@ ibus_compose_table_list_add_array (GSList        *compose_tables,
     int i;
     guint16 *ibus_compose_seqs = NULL;
 
+    g_assert (length >= 0);
     g_return_val_if_fail (data != NULL, compose_tables);
     g_return_val_if_fail (max_seq_len <= IBUS_MAX_COMPOSE_LEN, compose_tables);
 
