@@ -2,7 +2,8 @@
 /* vim:set et sts=4: */
 /* ibus - The Input Bus
  * Copyright (C) 2008-2010 Peng Huang <shawn.p.huang@gmail.com>
- * Copyright (C) 2008-2010 Red Hat, Inc.
+ * Copyright (C) 2015-2018 Takao Fujiwara <takao.fujiwara1@gmail.com>
+ * Copyright (C) 2008-2018 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -113,10 +114,7 @@ ibus_get_socket_path (void)
             display = g_strdup (_display);
         }
 
-        if (display == NULL) {
-            g_warning ("DISPLAY is empty! We use default DISPLAY (:0.0)");
-        }
-        else {
+        if (display) {
             p = display;
             hostname = display;
             for (; *p != ':' && *p != '\0'; p++);
@@ -144,6 +142,12 @@ ibus_get_socket_path (void)
                              ibus_get_local_machine_id (),
                              hostname,
                              displaynumber);
+        /* Qt5 IBus module has a hard-coded path and we cannot change this
+         * for the back compatibility.
+         * XDG_RUNTIME_DIR is not useful because it's generated by
+         * login but not `su` command and ibus-daemon can be run with `su`
+         * and we may change the path to XDG_CACHE_HOME in the future.
+         */
         path = g_build_filename (g_get_user_config_dir (),
                                  "ibus",
                                  "bus",
@@ -253,7 +257,11 @@ ibus_write_address (const gchar *address)
     g_return_if_fail (pf != NULL);
 
     fprintf (pf,
-        "# This file is created by ibus-daemon, please do not modify it\n"
+        "# This file is created by ibus-daemon, please do not modify it.\n"
+        "# This file allows processes on the machine to find the\n"
+        "# ibus session bus with the below address.\n"
+        "# If the IBUS_ADDRESS environment variable is set, it will\n"
+        "# be used rather than this file.\n"
         "IBUS_ADDRESS=%s\n"
         "IBUS_DAEMON_PID=%ld\n",
         address, (glong) getpid ());
@@ -290,6 +298,7 @@ ibus_init (void)
     IBUS_TYPE_ENGINE_DESC;
     IBUS_TYPE_OBSERVED_PATH;
     IBUS_TYPE_REGISTRY;
+    IBUS_TYPE_X_EVENT;
 }
 
 static GMainLoop *main_loop = NULL;
