@@ -1,8 +1,9 @@
 /* -*- mode: C; c-basic-offset: 4; indent-tabs-mode: nil; -*- */
 /* vim:set et sts=4: */
 /* bus - The Input Bus
- * Copyright (C) 2008-2010 Peng Huang <shawn.p.huang@gmail.com>
- * Copyright (C) 2008-2010 Red Hat, Inc.
+ * Copyright (C) 2008-2015 Peng Huang <shawn.p.huang@gmail.com>
+ * Copyright (C) 2018 Takao Fujiwara <takao.fujiwara1@gmail.com>
+ * Copyright (C) 2008-2018 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,6 +26,25 @@
 
 static GMarkupParser parser;
 
+G_DEFINE_BOXED_TYPE (IBusXML, ibus_xml,
+                     ibus_xml_copy,
+                     ibus_xml_free);
+
+XMLNode*
+ibus_xml_copy (const XMLNode *node)
+{
+    XMLNode *ret;
+
+    if (node == NULL)
+        return NULL;
+
+    ret = g_slice_new (XMLNode);
+
+    *ret = *node;
+
+    return ret;
+}
+
 void
 ibus_xml_free (XMLNode *node)
 {
@@ -221,8 +241,10 @@ ibus_xml_parse_file (const gchar *filename)
         return node;
     } while (0);
 
-    g_warning ("Parse %s failed: %s", filename, error->message);
-    g_error_free (error);
+    if (error) {
+        g_warning ("Parse %s failed: %s", filename, error->message);
+        g_error_free (error);
+    }
     g_markup_parse_context_free (context);
     return NULL;
 }
